# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:default_device_type) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `DEFAULT DEVICE TYPE`.
    The configuration can be set to default by setting it to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      default_device_type => 'SBT',
      ...
    }
  DESC

  newvalues(:clear, :CLEAR, :disk, :DISK, :sbt, :SBT, :sbt_tape, :SBT_TAPE)
  data_type("Enum['disk','DISK','sbt','SBT','sbt_tape','SBT_TAPE','clear','CLEAR','DISK (default)']")

  to_translate_to_resource do |raw_resource|
    raw_resource['DEFAULT_DEVICE_TYPE']
  end

  def insync?(is)
    if should.casecmp('clear').zero?
      is.include?('(default)')
    elsif should.include?('sbt') || should.include?('SBT')
      is.include?('sbt') or is.include?('SBT')
    else
      is.casecmp(should).zero?
    end
  end

  on_modify do
    if value.casecmp('clear').zero?
      rman("configure default device type #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    else
      rman("configure default device type to #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    end
  end
end
