# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:maxsetsize) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `MAXSETSIZE`.
    The configuration can be set to default by setting it to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      maxsetsize => '2047G',
      ...
    }
  DESC

  data_type('String[1]')

  to_translate_to_resource do |raw_resource|
    raw_resource['MAXSETSIZE']
  end

  def insync?(is)
    my_is = is.split.reduce('') { |mem, word| word.scan(/^\d+$/).any? ? "#{mem} #{word}" : "#{mem}#{word} " }.strip
    my_should = should.split.reduce('') { |mem, word| word.scan(/^\d+$/).any? ? "#{mem} #{word}" : "#{mem}#{word} " }.strip
    if my_should.to_s.casecmp('clear').zero?
      my_is.to_s.include?('(default)')
    else
      my_is.to_s == my_should.to_s
    end
  end

  on_modify do
    if value.to_s.casecmp('clear').zero?
      rman("configure maxsetsize #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    else
      rman("configure maxsetsize to #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    end
  end
end
